tuplettools.make_diminished_tuplet_from_duration_and_proportions_and_encourage_dots
===================================================================================

.. autofunction:: abjad.tools.tuplettools.make_diminished_tuplet_from_duration_and_proportions_and_encourage_dots.make_diminished_tuplet_from_duration_and_proportions_and_encourage_dots
